Module resolver

Module resolver 

xrust-net::resolver

Resolve a URL

Functions

resolve
Resolve a URL to the resource. Currently supports http and file schemes. This function operates asynchronously, so that security features can control the incoming data. However, it blocks until the resource is fully loaded (or an error occurs).